@@ -37,7 +37,7 @@ use PPI::Statement ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.219_001';
+	$VERSION = '1.221_01';
 	@ISA     = 'PPI::Statement';
 }
 
@@ -165,6 +165,10 @@ Returns true if it is a special reserved subroutine, or false if not.
 sub reserved {
 	my $self = shift;
 	my $name = $self->name or return '';
+	# perlsub is silent on whether reserveds can contain:
+	# - underscores;
+	# we allow them due to existing practice like CLONE_SKIP and __SUB__.
+	# - numbers; we allow them by PPI tradition.
 	$name eq uc $name;
 }
 
@@ -172,10 +176,6 @@ sub reserved {
 
 =pod
 
-=head1 TO DO
-
-- Write unit tests for this package
-
 =head1 SUPPORT
 
 See the L<support section|PPI/SUPPORT> in the main module.
