@@ -24,7 +24,7 @@ and newlines may not matter in most Perl code, but they matter in here-docs.
 They are also tricky to store as an object. They look sort of like an
 operator and a string, but they don't act like it. And they have a second
 section that should be something like a separate token, but isn't because a
-strong can span from above the here-doc content to below it.
+string can span from above the here-doc content to below it.
 
 So when parsing, this is what we do.
 
@@ -89,7 +89,7 @@ use PPI::Token ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.219_001';
+	$VERSION = '1.221_01';
 	@ISA     = 'PPI::Token';
 }
 
@@ -206,7 +206,7 @@ sub __TOKENIZER__on_char {
 	my $line;
 
 	# Suck in the HEREDOC
-	$token->{_heredoc} = [];
+	$token->{_heredoc} = \my @heredoc;
 	my $terminator = $token->{_terminator} . "\n";
 	while ( defined($line = $t->_get_line) ) {
 		if ( $line eq $terminator ) {
@@ -219,7 +219,7 @@ sub __TOKENIZER__on_char {
 		}
 
 		# Add the line
-		push @{$token->{_heredoc}}, $line;
+		push @heredoc, $line;
 	}
 
 	# End of file.
@@ -231,15 +231,15 @@ sub __TOKENIZER__on_char {
 		# it anyway (like perl itself does). In this case
 		# perl would normally throw a warning, but we will
 		# also ignore that as well.
-		pop @{$token->{_heredoc}};
+		pop @heredoc;
 		$token->{_terminator_line} = $line;
 	} else {
 		# The HereDoc was not properly terminated.
 		$token->{_terminator_line} = undef;
 
 		# Trim off the trailing whitespace
-		if ( defined $token->{_heredoc}->[-1] and $t->{source_eof_chop} ) {
-			chop $token->{_heredoc}->[-1];
+		if ( defined $heredoc[-1] and $t->{source_eof_chop} ) {
+			chop $heredoc[-1];
 			$t->{source_eof_chop} = '';
 		}
 	}
