@@ -9,14 +9,11 @@ use Params::Util qw{_INSTANCE _SCALAR0 _ARRAY0};
 
 use vars qw{$VERSION @ISA @EXPORT_OK};
 BEGIN {
-	$VERSION   = '1.219_001';
+	$VERSION   = '1.221_01';
 	@ISA       = 'Exporter';
 	@EXPORT_OK = qw{_Document _slurp};
 }
 
-# Alarms are used to catch unexpectedly slow and complex documents
-use constant HAVE_ALARM   => !  ( $^O eq 'MSWin32' or $^O eq 'cygwin' );
-
 # 5.8.7 was the first version to resolve the notorious
 # "unicode length caching" bug.
 use constant HAVE_UNICODE => !! ( $] >= 5.008007 );
